@@ -178,8 +178,14 @@ case "$switch" in
      [ "$BOOTUP" = "color" ] && $SETCOLOR_WARNING
      echo "$msg_this_is_for_drbl_server_not_for_clonezilla_server_edition"
      [ "$BOOTUP" = "color" ] && $SETCOLOR_NORMAL
-     echo -n $msg_press_enter_to_continue
-     read
+     echo "$msg_are_u_sure_u_want_to_continue"
+     echo -n "[Y/n] "
+     read drbl_live_ans
+     case "$drbl_live_ans" in
+        n|N|[nN][oO]) echo "$msg_program_stop" 
+	              exit 1 ;;
+        *) echo "$msg_ok_let_do_it" ;;
+     esac
 
      # config network first:
      config_network
